@@ -19,13 +19,17 @@
  * 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
 #include <glib-object.h>
 #include <string.h>
-#include <glib/gi18n-lib.h>
-#include <gnome-keyring.h>
 #include <dbus/dbus-glib.h>
 
+#ifdef HAVE_GNOME_KEYRING
+#include <gnome-keyring.h>
+#endif
+
 #include <gdu/gdu.h>
 #include "gdu-gtk.h"
 
@@ -805,6 +809,7 @@ out:
         return secret;
 }
 
+#ifdef HAVE_GNOME_KEYRING
 static GnomeKeyringPasswordSchema encrypted_device_password_schema = {
         GNOME_KEYRING_ITEM_GENERIC_SECRET,
         {
@@ -812,6 +817,7 @@ static GnomeKeyringPasswordSchema encrypted_device_password_schema = {
                 { NULL, 0 }
         }
 };
+#endif
 
 char *
 gdu_util_dialog_ask_for_new_secret (GtkWidget      *parent_window,
@@ -891,10 +897,12 @@ gdu_util_dialog_ask_for_secret (GtkWidget      *parent_window,
         }
 
         if (!bypass_keyring) {
+#ifdef HAVE_GNOME_KEYRING
+                password = NULL;
                 if (gnome_keyring_find_password_sync (&encrypted_device_password_schema,
                                                       &password,
                                                       "luks-device-uuid", uuid,
-                                                      NULL) == GNOME_KEYRING_RESULT_OK) {
+                                                      NULL) == GNOME_KEYRING_RESULT_OK && password != NULL) {
                         /* By contract, the caller is responsible for scrubbing the password
                          * so dupping the string into pageable memory is "fine". Or not?
                          */
@@ -902,6 +910,7 @@ gdu_util_dialog_ask_for_secret (GtkWidget      *parent_window,
                         gnome_keyring_free_password (password);
                         goto out;
                 }
+#endif
         }
 
         if (gdu_device_is_partition (device)) {
@@ -936,6 +945,7 @@ gdu_util_dialog_ask_for_secret (GtkWidget      *parent_window,
         if (asked_user != NULL)
                 *asked_user = TRUE;
 
+#ifdef HAVE_GNOME_KEYRING
         if (secret != NULL && (save_in_keyring || save_in_keyring_session)) {
                 const char *keyring;
                 gchar *name;
@@ -957,6 +967,7 @@ gdu_util_dialog_ask_for_secret (GtkWidget      *parent_window,
 
                 g_free (name);
         }
+#endif
 
 out:
         if (device != NULL)
@@ -1029,11 +1040,13 @@ gdu_util_dialog_change_secret (GtkWidget       *parent_window,
                 goto out;
         }
 
+#ifdef HAVE_GNOME_KEYRING
         if (!bypass_keyring) {
+                password = NULL;
                 if (gnome_keyring_find_password_sync (&encrypted_device_password_schema,
                                                       &password,
                                                       "luks-device-uuid", uuid,
-                                                      NULL) == GNOME_KEYRING_RESULT_OK) {
+                                                      NULL) == GNOME_KEYRING_RESULT_OK && password != NULL) {
                         /* By contract, the caller is responsible for scrubbing the password
                          * so dupping the string into pageable memory "fine". Or not?
                          */
@@ -1041,6 +1054,7 @@ gdu_util_dialog_change_secret (GtkWidget       *parent_window,
                         gnome_keyring_free_password (password);
                 }
         }
+#endif
 
         if (gdu_device_is_partition (device)) {
                 char *s;
@@ -1714,3 +1728,33 @@ gdu_util_get_pixbuf_for_presentable_at_pixel_size (GduPresentable *presentable,
         return pixbuf;
 }
 
+/* ---------------------------------------------------------------------------------------------------- */
+
+void
+gdu_util_get_mix_color (GtkWidget    *widget,
+                        GtkStateType  state,
+                        gchar        *color_buf,
+                        gsize         color_buf_size)
+{
+        GtkStyle *style;
+        GdkColor color = {0};
+
+        g_return_if_fail (GTK_IS_WIDGET (widget));
+        g_return_if_fail (color_buf != NULL);
+
+        /* This color business shouldn't be this hard... */
+        style = gtk_widget_get_style (widget);
+#define BLEND_FACTOR 0.7
+        color.red   = style->text[state].red   * BLEND_FACTOR +
+                      style->base[state].red   * (1.0 - BLEND_FACTOR);
+        color.green = style->text[state].green * BLEND_FACTOR +
+                      style->base[state].green * (1.0 - BLEND_FACTOR);
+        color.blue  = style->text[state].blue  * BLEND_FACTOR +
+                      style->base[state].blue  * (1.0 - BLEND_FACTOR);
+#undef BLEND_FACTOR
+        snprintf (color_buf,
+                  color_buf_size, "#%02x%02x%02x",
+                  (color.red >> 8),
+                  (color.green >> 8),
+                  (color.blue >> 8));
+}
